package fastly

import "testing"

func TestClient_ACLEntries(t *testing.T) {
}

func TestClient_ListACLEntries_validation(t *testing.T) {
	var err error
	_, err = testClient.ListACLEntries(&ListACLEntriesInput{
		Service: "",
	})
	if err != ErrMissingService {
		t.Errorf("bad error: %s", err)
	}

	_, err = testClient.ListACLEntries(&ListACLEntriesInput{
		Service: "foo",
		ACL:     "",
	})
	if err != ErrMissingACL {
		t.Errorf("bad error: %s", err)
	}
}

func TestClient_CreateACLEntry_validation(t *testing.T) {
	var err error
	_, err = testClient.CreateACLEntry(&CreateACLEntryInput{
		Service: "",
	})
	if err != ErrMissingService {
		t.Errorf("bad error: %s", err)
	}

	_, err = testClient.CreateACLEntry(&CreateACLEntryInput{
		Service: "foo",
		ACL:     "",
	})
	if err != ErrMissingACL {
		t.Errorf("bad error: %s", err)
	}
}

func TestClient_GetACLEntry_validation(t *testing.T) {
	var err error
	_, err = testClient.GetACLEntry(&GetACLEntryInput{
		Service: "",
	})
	if err != ErrMissingService {
		t.Errorf("bad error: %s", err)
	}

	_, err = testClient.GetACLEntry(&GetACLEntryInput{
		Service: "foo",
		ACL:     "",
	})
	if err != ErrMissingACL {
		t.Errorf("bad error: %s", err)
	}

	_, err = testClient.GetACLEntry(&GetACLEntryInput{
		Service: "foo",
		ACL:     "acl",
		ID:      "",
	})
	if err != ErrMissingID {
		t.Errorf("bad error: %s", err)
	}
}

func TestClient_UpdateACLEntry_validation(t *testing.T) {
	var err error
	_, err = testClient.UpdateACLEntry(&UpdateACLEntryInput{
		Service: "",
	})
	if err != ErrMissingService {
		t.Errorf("bad error: %s", err)
	}

	_, err = testClient.UpdateACLEntry(&UpdateACLEntryInput{
		Service: "foo",
		ACL:     "",
	})
	if err != ErrMissingACL {
		t.Errorf("bad error: %s", err)
	}

	_, err = testClient.UpdateACLEntry(&UpdateACLEntryInput{
		Service: "foo",
		ACL:     "acl",
		ID:      "",
	})
	if err != ErrMissingID {
		t.Errorf("bad error: %s", err)
	}
}

func TestClient_DeleteACLEntry_validation(t *testing.T) {
	var err error
	err = testClient.DeleteACLEntry(&DeleteACLEntryInput{
		Service: "",
	})
	if err != ErrMissingService {
		t.Errorf("bad error: %s", err)
	}

	err = testClient.DeleteACLEntry(&DeleteACLEntryInput{
		Service: "foo",
		ACL:     "",
	})
	if err != ErrMissingACL {
		t.Errorf("bad error: %s", err)
	}

	err = testClient.DeleteACLEntry(&DeleteACLEntryInput{
		Service: "foo",
		ACL:     "acl",
		ID:      "",
	})
	if err != ErrMissingID {
		t.Errorf("bad error: %s", err)
	}
}

func TestClient_BatchModifyACLEntries_validation(t *testing.T) {
	var err error
	err = testClient.BatchModifyACLEntries(&BatchModifyACLEntriesInput{
		Service: "",
	})
	if err != ErrMissingService {
		t.Errorf("bad error: %s", err)
	}
	err = testClient.BatchModifyACLEntries(&BatchModifyACLEntriesInput{
		Service: "foo",
		ACL:     "",
	})
	if err != ErrMissingACL {
		t.Errorf("bad error: %s", err)
	}

	oversizedACLEntries := make([]*BatchACLEntry, BatchModifyMaximumOperations+1)
	err = testClient.BatchModifyACLEntries(&BatchModifyACLEntriesInput{
		Service: "foo",
		ACL:     "bar",
		Entries: oversizedACLEntries,
	})
	if err != ErrBatchUpdateMaximumOperationsExceeded {
		t.Errorf("bad error: %s", err)
	}

}
